@@ -2,7 +2,8 @@
 #' @name get_tiles
 #' @description Get map tiles based on a spatial object extent. Maps can be
 #' fetched from various map servers.
-#' @param x an sf, sfc, bbox or SpatExtent object. If \code{x} is a SpatExtent it
+#' @param x an sf, sfc, bbox, SpatRaster, SpatVerctor or SpatExtent object.
+#' If \code{x} is a SpatExtent it
 #' must express coordinates in lon/lat WGS84 (epsg:4326).
 #' @param provider the tile server from which to get the map. It can be a name
 #' (see Details for providers) or a named list like this one: \code{
@@ -15,7 +16,7 @@
 #' @param verbose if TRUE, tiles filepaths, zoom level and citation are displayed.
 #' @param apikey API key, needed for Thunderforest servers
 #' @param cachedir name of a directory used to cache tiles. If not set, tiles
-#' are cached in a \link[base:tempdir]{tempdir} folder.
+#' are cached in a \link[base:tempfile]{tempdir} folder.
 #' @param forceDownload if TRUE, existing cached tiles may be overwritten
 #' @details
 #' Zoom levels are described on the OpenStreetMap wiki:
@@ -43,7 +44,7 @@
 #' "Wikimedia",\cr
 #' @export
 #' @return A SpatRaster is returned.
-#' @importFrom terra ext project rast gdal_version
+#' @importFrom terra ext project rast as.polygons 'RGB<-' gdal
 #' @importFrom sf st_is st_transform st_geometry<- st_buffer st_geometry
 #' st_bbox st_as_sfc st_crs
 #' @examples
@@ -71,10 +72,10 @@ get_tiles <- function(x,
                       apikey,
                       cachedir,
                       forceDownload = FALSE) {
-
-  if (gdal_version() < "3.0.4"){
-    warning(paste0("Your GDAL version is ",gdal_version(),
-                ". You need GDAL >= 3.0.4 to use maptiles."),
+   # gdal_version is obsolete.
+  if (gdal() < "3.0.4"){
+    warning(paste0("Your GDAL version is ",gdal(),
+                   ". You need GDAL >= 3.0.4 to use maptiles."),
             call. = FALSE)
     return(invisible(NULL))
   }
@@ -83,6 +84,15 @@ get_tiles <- function(x,
     x <- st_as_sfc(x)
   }
 
+	if(inherits(x, 'SpatRaster')){
+		x <- terra::as.polygons(x, extent = TRUE)
+		x <- terra::project(x, "epsg:4326")
+		x <- terra::ext(x)
+	} else if(inherits(x, 'SpatVector')){
+		x <- terra::project(x, "epsg:4326")
+		x <- terra::ext(x)
+	}
+
   if(inherits(x, c('sf', 'sfc'))){
     origin_proj <- st_crs(x)$wkt
     # test for single point (apply buffer to obtain a correct bbox)
@@ -102,7 +112,8 @@ get_tiles <- function(x,
     bbx <- as.vector(x)[c(1,3,2,4)]
     cb <- bbx
   } else {
-    stop(paste0("x should be an sf, sfc, bbox or SpatExtent object"),
+    stop(paste0("x should be an sf, sfc, bbox, SpatRaster,",
+                " SpatVector or SpatExtent object"),
          call. = FALSE)
   }
 
@@ -156,6 +167,9 @@ get_tiles <- function(x,
     rout <- terra::crop(rout, cb[c(1, 3, 2, 4)])
   }
 
+  # set R, G, B channels, such that plot(rout) will go to plotRGB
+  terra::RGB(rout) <- 1:3
+
   rout
 }
 
@@ -229,6 +243,17 @@ compose_tile_grid <- function(tile_grid, images) {
     # special for png tiles
     if (tile_grid$ext == "png") {
       img <- png::readPNG(img) * 255
+
+      # Give transparency if available
+      if (dim(img)[3] == 4) {
+        nrow <- dim(img)[1]
+        for (j in seq_len(nrow)) {
+          row <- img[j, , ]
+          alpha <- row[, 4] == 0
+          row[alpha, ] <- NA
+          img[j, , ] <- row
+        }
+      }
     }
 
     # compose brick raster
